"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v1.1.33
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from ory_client.api_client import ApiClient, Endpoint as _Endpoint
from ory_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from ory_client.model.active_project_in_console import ActiveProjectInConsole
from ory_client.model.create_project_api_key_request import CreateProjectApiKeyRequest
from ory_client.model.create_project_body import CreateProjectBody
from ory_client.model.error_generic import ErrorGeneric
from ory_client.model.generic_error import GenericError
from ory_client.model.json_patch import JsonPatch
from ory_client.model.project import Project
from ory_client.model.project_api_key import ProjectApiKey
from ory_client.model.project_api_keys import ProjectApiKeys
from ory_client.model.project_members import ProjectMembers
from ory_client.model.project_metadata_list import ProjectMetadataList
from ory_client.model.set_active_project_in_console_body import SetActiveProjectInConsoleBody
from ory_client.model.set_project import SetProject
from ory_client.model.successful_project_update import SuccessfulProjectUpdate


class ProjectApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_project_endpoint = _Endpoint(
            settings={
                'response_type': (Project,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects',
                'operation_id': 'create_project',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'create_project_body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'create_project_body':
                        (CreateProjectBody,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'create_project_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_project_api_key_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectApiKey,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project}/tokens',
                'operation_id': 'create_project_api_key',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project',
                    'create_project_api_key_request',
                ],
                'required': [
                    'project',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project':
                        (str,),
                    'create_project_api_key_request':
                        (CreateProjectApiKeyRequest,),
                },
                'attribute_map': {
                    'project': 'project',
                },
                'location_map': {
                    'project': 'path',
                    'create_project_api_key_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_project_api_key_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project}/tokens/{token_id}',
                'operation_id': 'delete_project_api_key',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'project',
                    'token_id',
                ],
                'required': [
                    'project',
                    'token_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project':
                        (str,),
                    'token_id':
                        (str,),
                },
                'attribute_map': {
                    'project': 'project',
                    'token_id': 'token_id',
                },
                'location_map': {
                    'project': 'path',
                    'token_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_active_project_in_console_endpoint = _Endpoint(
            settings={
                'response_type': (ActiveProjectInConsole,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/console/active/project',
                'operation_id': 'get_active_project_in_console',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_endpoint = _Endpoint(
            settings={
                'response_type': (Project,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project_id}',
                'operation_id': 'get_project',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                ],
                'required': [
                    'project_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'project_id',
                },
                'location_map': {
                    'project_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_members_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectMembers,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project_id}/members',
                'operation_id': 'get_project_members',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                ],
                'required': [
                    'project_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'project_id',
                },
                'location_map': {
                    'project_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_project_api_keys_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectApiKeys,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project}/tokens',
                'operation_id': 'list_project_api_keys',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project',
                ],
                'required': [
                    'project',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project':
                        (str,),
                },
                'attribute_map': {
                    'project': 'project',
                },
                'location_map': {
                    'project': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_projects_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectMetadataList,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects',
                'operation_id': 'list_projects',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.patch_project_endpoint = _Endpoint(
            settings={
                'response_type': (SuccessfulProjectUpdate,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project_id}',
                'operation_id': 'patch_project',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'json_patch',
                ],
                'required': [
                    'project_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'json_patch':
                        ([JsonPatch],),
                },
                'attribute_map': {
                    'project_id': 'project_id',
                },
                'location_map': {
                    'project_id': 'path',
                    'json_patch': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.purge_project_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project_id}',
                'operation_id': 'purge_project',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                ],
                'required': [
                    'project_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'project_id',
                },
                'location_map': {
                    'project_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.remove_project_member_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project_id}/members/{member_id}',
                'operation_id': 'remove_project_member',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'member_id',
                ],
                'required': [
                    'project_id',
                    'member_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'member_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'project_id',
                    'member_id': 'member_id',
                },
                'location_map': {
                    'project_id': 'path',
                    'member_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.set_active_project_in_console_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/console/active/project',
                'operation_id': 'set_active_project_in_console',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'set_active_project_in_console_body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'set_active_project_in_console_body':
                        (SetActiveProjectInConsoleBody,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'set_active_project_in_console_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.set_project_endpoint = _Endpoint(
            settings={
                'response_type': (SuccessfulProjectUpdate,),
                'auth': [
                    'oryAccessToken'
                ],
                'endpoint_path': '/projects/{project_id}',
                'operation_id': 'set_project',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'set_project',
                ],
                'required': [
                    'project_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'set_project':
                        (SetProject,),
                },
                'attribute_map': {
                    'project_id': 'project_id',
                },
                'location_map': {
                    'project_id': 'path',
                    'set_project': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def create_project(
        self,
        **kwargs
    ):
        """Create a Project  # noqa: E501

        Creates a new project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_project(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            create_project_body (CreateProjectBody): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Project
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.create_project_endpoint.call_with_http_info(**kwargs)

    def create_project_api_key(
        self,
        project,
        **kwargs
    ):
        """Create project API token  # noqa: E501

        Create an API token for a project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_project_api_key(project, async_req=True)
        >>> result = thread.get()

        Args:
            project (str): The Project ID or Project slug

        Keyword Args:
            create_project_api_key_request (CreateProjectApiKeyRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ProjectApiKey
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project'] = \
            project
        return self.create_project_api_key_endpoint.call_with_http_info(**kwargs)

    def delete_project_api_key(
        self,
        project,
        token_id,
        **kwargs
    ):
        """Delete project API token  # noqa: E501

        Deletes an API token and immediately removes it.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_project_api_key(project, token_id, async_req=True)
        >>> result = thread.get()

        Args:
            project (str): The Project ID or Project slug
            token_id (str): The Token ID

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project'] = \
            project
        kwargs['token_id'] = \
            token_id
        return self.delete_project_api_key_endpoint.call_with_http_info(**kwargs)

    def get_active_project_in_console(
        self,
        **kwargs
    ):
        """Returns the Ory Network Project selected in the Ory Network Console  # noqa: E501

        Use this API to get your active project in the Ory Network Console UI.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_active_project_in_console(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ActiveProjectInConsole
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_active_project_in_console_endpoint.call_with_http_info(**kwargs)

    def get_project(
        self,
        project_id,
        **kwargs
    ):
        """Get a Project  # noqa: E501

        Get a projects you have access to by its ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project(project_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str): Project ID  The project's ID.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Project
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project_id'] = \
            project_id
        return self.get_project_endpoint.call_with_http_info(**kwargs)

    def get_project_members(
        self,
        project_id,
        **kwargs
    ):
        """Get all members associated with this project  # noqa: E501

        This endpoint requires the user to be a member of the project with the role `OWNER` or `DEVELOPER`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_members(project_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str): Project ID  The project's ID.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ProjectMembers
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project_id'] = \
            project_id
        return self.get_project_members_endpoint.call_with_http_info(**kwargs)

    def list_project_api_keys(
        self,
        project,
        **kwargs
    ):
        """List a project's API Tokens  # noqa: E501

        A list of all the project's API tokens.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_project_api_keys(project, async_req=True)
        >>> result = thread.get()

        Args:
            project (str): The Project ID or Project slug

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ProjectApiKeys
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project'] = \
            project
        return self.list_project_api_keys_endpoint.call_with_http_info(**kwargs)

    def list_projects(
        self,
        **kwargs
    ):
        """List All Projects  # noqa: E501

        Lists all projects you have access to.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_projects(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ProjectMetadataList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_projects_endpoint.call_with_http_info(**kwargs)

    def patch_project(
        self,
        project_id,
        **kwargs
    ):
        """Patch an Ory Network Project Configuration  # noqa: E501

        Deprecated: Use the `patchProjectWithRevision` endpoint instead to specify the exact revision the patch was generated for.  This endpoints allows you to patch individual Ory Network project configuration keys for Ory's services (identity, permission, ...). The configuration format is fully compatible with the open source projects for the respective services (e.g. Ory Kratos for Identity, Ory Keto for Permissions).  This endpoint expects the `version` key to be set in the payload. If it is unset, it will try to import the config as if it is from the most recent version.  If you have an older version of a configuration, you should set the version key in the payload!  While this endpoint is able to process all configuration items related to features (e.g. password reset), it does not support operational configuration items (e.g. port, tracing, logging) otherwise available in the open source.  For configuration items that can not be translated to the Ory Network, this endpoint will return a list of warnings to help you understand which parts of your config could not be processed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_project(project_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str): Project ID  The project's ID.

        Keyword Args:
            json_patch ([JsonPatch]): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SuccessfulProjectUpdate
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project_id'] = \
            project_id
        return self.patch_project_endpoint.call_with_http_info(**kwargs)

    def purge_project(
        self,
        project_id,
        **kwargs
    ):
        """Irrecoverably purge a project  # noqa: E501

        !! Use with extreme caution !!  Using this API endpoint you can purge (completely delete) a project and its data. This action can not be undone and will delete ALL your data.  !! Use with extreme caution !!  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.purge_project(project_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str): Project ID  The project's ID.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project_id'] = \
            project_id
        return self.purge_project_endpoint.call_with_http_info(**kwargs)

    def remove_project_member(
        self,
        project_id,
        member_id,
        **kwargs
    ):
        """Remove a member associated with this project  # noqa: E501

        This also sets their invite status to `REMOVED`. This endpoint requires the user to be a member of the project with the role `OWNER`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove_project_member(project_id, member_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str): Project ID  The project's ID.
            member_id (str): Member ID

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project_id'] = \
            project_id
        kwargs['member_id'] = \
            member_id
        return self.remove_project_member_endpoint.call_with_http_info(**kwargs)

    def set_active_project_in_console(
        self,
        **kwargs
    ):
        """Sets the Ory Network Project active in the Ory Network Console  # noqa: E501

        Use this API to set your active project in the Ory Network Console UI.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_active_project_in_console(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            set_active_project_in_console_body (SetActiveProjectInConsoleBody): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.set_active_project_in_console_endpoint.call_with_http_info(**kwargs)

    def set_project(
        self,
        project_id,
        **kwargs
    ):
        """Update an Ory Network Project Configuration  # noqa: E501

        This endpoints allows you to update the Ory Network project configuration for individual services (identity, permission, ...). The configuration is fully compatible with the open source projects for the respective services (e.g. Ory Kratos for Identity, Ory Keto for Permissions).  This endpoint expects the `version` key to be set in the payload. If it is unset, it will try to import the config as if it is from the most recent version.  If you have an older version of a configuration, you should set the version key in the payload!  While this endpoint is able to process all configuration items related to features (e.g. password reset), it does not support operational configuration items (e.g. port, tracing, logging) otherwise available in the open source.  For configuration items that can not be translated to the Ory Network, this endpoint will return a list of warnings to help you understand which parts of your config could not be processed.  Be aware that updating any service's configuration will completely override your current configuration for that service!  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_project(project_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str): Project ID  The project's ID.

        Keyword Args:
            set_project (SetProject): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SuccessfulProjectUpdate
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['project_id'] = \
            project_id
        return self.set_project_endpoint.call_with_http_info(**kwargs)




"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v1.1.33
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import unittest

import ory_client
from ory_client.api.frontend_api import FrontendApi  # noqa: E501


class TestFrontendApi(unittest.TestCase):
    """FrontendApi unit test stubs"""

    def setUp(self):
        self.api = FrontendApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_browser_login_flow(self):
        """Test case for create_browser_login_flow

        Create Login Flow for Browsers  # noqa: E501
        """
        pass

    def test_create_browser_logout_flow(self):
        """Test case for create_browser_logout_flow

        Create a Logout URL for Browsers  # noqa: E501
        """
        pass

    def test_create_browser_recovery_flow(self):
        """Test case for create_browser_recovery_flow

        Create Recovery Flow for Browsers  # noqa: E501
        """
        pass

    def test_create_browser_registration_flow(self):
        """Test case for create_browser_registration_flow

        Create Registration Flow for Browsers  # noqa: E501
        """
        pass

    def test_create_browser_settings_flow(self):
        """Test case for create_browser_settings_flow

        Create Settings Flow for Browsers  # noqa: E501
        """
        pass

    def test_create_browser_verification_flow(self):
        """Test case for create_browser_verification_flow

        Create Verification Flow for Browser Clients  # noqa: E501
        """
        pass

    def test_create_native_login_flow(self):
        """Test case for create_native_login_flow

        Create Login Flow for Native Apps  # noqa: E501
        """
        pass

    def test_create_native_recovery_flow(self):
        """Test case for create_native_recovery_flow

        Create Recovery Flow for Native Apps  # noqa: E501
        """
        pass

    def test_create_native_registration_flow(self):
        """Test case for create_native_registration_flow

        Create Registration Flow for Native Apps  # noqa: E501
        """
        pass

    def test_create_native_settings_flow(self):
        """Test case for create_native_settings_flow

        Create Settings Flow for Native Apps  # noqa: E501
        """
        pass

    def test_create_native_verification_flow(self):
        """Test case for create_native_verification_flow

        Create Verification Flow for Native Apps  # noqa: E501
        """
        pass

    def test_disable_my_other_sessions(self):
        """Test case for disable_my_other_sessions

        Disable my other sessions  # noqa: E501
        """
        pass

    def test_disable_my_session(self):
        """Test case for disable_my_session

        Disable one of my sessions  # noqa: E501
        """
        pass

    def test_exchange_session_token(self):
        """Test case for exchange_session_token

        Exchange Session Token  # noqa: E501
        """
        pass

    def test_get_flow_error(self):
        """Test case for get_flow_error

        Get User-Flow Errors  # noqa: E501
        """
        pass

    def test_get_login_flow(self):
        """Test case for get_login_flow

        Get Login Flow  # noqa: E501
        """
        pass

    def test_get_recovery_flow(self):
        """Test case for get_recovery_flow

        Get Recovery Flow  # noqa: E501
        """
        pass

    def test_get_registration_flow(self):
        """Test case for get_registration_flow

        Get Registration Flow  # noqa: E501
        """
        pass

    def test_get_settings_flow(self):
        """Test case for get_settings_flow

        Get Settings Flow  # noqa: E501
        """
        pass

    def test_get_verification_flow(self):
        """Test case for get_verification_flow

        Get Verification Flow  # noqa: E501
        """
        pass

    def test_get_web_authn_java_script(self):
        """Test case for get_web_authn_java_script

        Get WebAuthn JavaScript  # noqa: E501
        """
        pass

    def test_list_my_sessions(self):
        """Test case for list_my_sessions

        Get My Active Sessions  # noqa: E501
        """
        pass

    def test_perform_native_logout(self):
        """Test case for perform_native_logout

        Perform Logout for Native Apps  # noqa: E501
        """
        pass

    def test_to_session(self):
        """Test case for to_session

        Check Who the Current HTTP Session Belongs To  # noqa: E501
        """
        pass

    def test_update_login_flow(self):
        """Test case for update_login_flow

        Submit a Login Flow  # noqa: E501
        """
        pass

    def test_update_logout_flow(self):
        """Test case for update_logout_flow

        Update Logout Flow  # noqa: E501
        """
        pass

    def test_update_recovery_flow(self):
        """Test case for update_recovery_flow

        Complete Recovery Flow  # noqa: E501
        """
        pass

    def test_update_registration_flow(self):
        """Test case for update_registration_flow

        Update Registration Flow  # noqa: E501
        """
        pass

    def test_update_settings_flow(self):
        """Test case for update_settings_flow

        Complete Settings Flow  # noqa: E501
        """
        pass

    def test_update_verification_flow(self):
        """Test case for update_verification_flow

        Complete Verification Flow  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v1.1.33
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.accept_o_auth2_consent_request_session import AcceptOAuth2ConsentRequestSession
from ory_client.model.o_auth2_consent_request import OAuth2ConsentRequest
from ory_client.model.o_auth2_consent_session_expires_at import OAuth2ConsentSessionExpiresAt
from ory_client.model.string_slice_json_format import StringSliceJSONFormat
globals()['AcceptOAuth2ConsentRequestSession'] = AcceptOAuth2ConsentRequestSession
globals()['OAuth2ConsentRequest'] = OAuth2ConsentRequest
globals()['OAuth2ConsentSessionExpiresAt'] = OAuth2ConsentSessionExpiresAt
globals()['StringSliceJSONFormat'] = StringSliceJSONFormat
from ory_client.model.o_auth2_consent_session import OAuth2ConsentSession


class TestOAuth2ConsentSession(unittest.TestCase):
    """OAuth2ConsentSession unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOAuth2ConsentSession(self):
        """Test OAuth2ConsentSession"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OAuth2ConsentSession()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v1.1.33
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import unittest

import ory_client
from ory_client.api.relationship_api import RelationshipApi  # noqa: E501


class TestRelationshipApi(unittest.TestCase):
    """RelationshipApi unit test stubs"""

    def setUp(self):
        self.api = RelationshipApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check_opl_syntax(self):
        """Test case for check_opl_syntax

        Check the syntax of an OPL file  # noqa: E501
        """
        pass

    def test_create_relationship(self):
        """Test case for create_relationship

        Create a Relationship  # noqa: E501
        """
        pass

    def test_delete_relationships(self):
        """Test case for delete_relationships

        Delete Relationships  # noqa: E501
        """
        pass

    def test_get_relationships(self):
        """Test case for get_relationships

        Query relationships  # noqa: E501
        """
        pass

    def test_list_relationship_namespaces(self):
        """Test case for list_relationship_namespaces

        Query namespaces  # noqa: E501
        """
        pass

    def test_patch_relationships(self):
        """Test case for patch_relationships

        Patch Multiple Relationships  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from ory_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from ory_client.model.accept_o_auth2_consent_request import AcceptOAuth2ConsentRequest
from ory_client.model.accept_o_auth2_consent_request_session import AcceptOAuth2ConsentRequestSession
from ory_client.model.accept_o_auth2_login_request import AcceptOAuth2LoginRequest
from ory_client.model.active_project_in_console import ActiveProjectInConsole
from ory_client.model.authenticator_assurance_level import AuthenticatorAssuranceLevel
from ory_client.model.batch_patch_identities_response import BatchPatchIdentitiesResponse
from ory_client.model.check_opl_syntax_result import CheckOplSyntaxResult
from ory_client.model.check_permission_result import CheckPermissionResult
from ory_client.model.cloud_account import CloudAccount
from ory_client.model.continue_with import ContinueWith
from ory_client.model.continue_with_set_ory_session_token import ContinueWithSetOrySessionToken
from ory_client.model.continue_with_verification_ui import ContinueWithVerificationUi
from ory_client.model.continue_with_verification_ui_flow import ContinueWithVerificationUiFlow
from ory_client.model.courier_message_status import CourierMessageStatus
from ory_client.model.courier_message_type import CourierMessageType
from ory_client.model.create_custom_domain_body import CreateCustomDomainBody
from ory_client.model.create_identity_body import CreateIdentityBody
from ory_client.model.create_json_web_key_set import CreateJsonWebKeySet
from ory_client.model.create_project_api_key_request import CreateProjectApiKeyRequest
from ory_client.model.create_project_body import CreateProjectBody
from ory_client.model.create_project_branding import CreateProjectBranding
from ory_client.model.create_project_brandings_body import CreateProjectBrandingsBody
from ory_client.model.create_project_invite import CreateProjectInvite
from ory_client.model.create_project_invites_response import CreateProjectInvitesResponse
from ory_client.model.create_recovery_code_for_identity_body import CreateRecoveryCodeForIdentityBody
from ory_client.model.create_recovery_link_for_identity_body import CreateRecoveryLinkForIdentityBody
from ory_client.model.create_relationship_body import CreateRelationshipBody
from ory_client.model.create_subscription_body import CreateSubscriptionBody
from ory_client.model.custom_domain import CustomDomain
from ory_client.model.delete_my_sessions_count import DeleteMySessionsCount
from ory_client.model.error_authenticator_assurance_level_not_satisfied import ErrorAuthenticatorAssuranceLevelNotSatisfied
from ory_client.model.error_browser_location_change_required import ErrorBrowserLocationChangeRequired
from ory_client.model.error_flow_replaced import ErrorFlowReplaced
from ory_client.model.error_generic import ErrorGeneric
from ory_client.model.error_o_auth2 import ErrorOAuth2
from ory_client.model.expanded_permission_tree import ExpandedPermissionTree
from ory_client.model.flow_error import FlowError
from ory_client.model.generic_error import GenericError
from ory_client.model.generic_error_content import GenericErrorContent
from ory_client.model.generic_usage import GenericUsage
from ory_client.model.get_managed_identity_schema_location import GetManagedIdentitySchemaLocation
from ory_client.model.get_version200_response import GetVersion200Response
from ory_client.model.health_not_ready_status import HealthNotReadyStatus
from ory_client.model.health_status import HealthStatus
from ory_client.model.identity import Identity
from ory_client.model.identity_credentials import IdentityCredentials
from ory_client.model.identity_credentials_oidc import IdentityCredentialsOidc
from ory_client.model.identity_credentials_oidc_provider import IdentityCredentialsOidcProvider
from ory_client.model.identity_credentials_password import IdentityCredentialsPassword
from ory_client.model.identity_credentials_type import IdentityCredentialsType
from ory_client.model.identity_patch import IdentityPatch
from ory_client.model.identity_patch_response import IdentityPatchResponse
from ory_client.model.identity_schema_container import IdentitySchemaContainer
from ory_client.model.identity_schema_preset import IdentitySchemaPreset
from ory_client.model.identity_schema_presets import IdentitySchemaPresets
from ory_client.model.identity_schemas import IdentitySchemas
from ory_client.model.identity_state import IdentityState
from ory_client.model.identity_with_credentials import IdentityWithCredentials
from ory_client.model.identity_with_credentials_oidc import IdentityWithCredentialsOidc
from ory_client.model.identity_with_credentials_oidc_config import IdentityWithCredentialsOidcConfig
from ory_client.model.identity_with_credentials_oidc_config_provider import IdentityWithCredentialsOidcConfigProvider
from ory_client.model.identity_with_credentials_password import IdentityWithCredentialsPassword
from ory_client.model.identity_with_credentials_password_config import IdentityWithCredentialsPasswordConfig
from ory_client.model.internal_get_project_branding_body import InternalGetProjectBrandingBody
from ory_client.model.internal_is_owner_for_project_by_slug_body import InternalIsOwnerForProjectBySlugBody
from ory_client.model.internal_is_owner_for_project_by_slug_response import InternalIsOwnerForProjectBySlugResponse
from ory_client.model.internal_provision_mock_subscription import InternalProvisionMockSubscription
from ory_client.model.introspected_o_auth2_token import IntrospectedOAuth2Token
from ory_client.model.is_owner_for_project_by_slug import IsOwnerForProjectBySlug
from ory_client.model.is_ready200_response import IsReady200Response
from ory_client.model.is_ready503_response import IsReady503Response
from ory_client.model.json_patch import JsonPatch
from ory_client.model.json_patch_document import JsonPatchDocument
from ory_client.model.json_web_key import JsonWebKey
from ory_client.model.json_web_key_set import JsonWebKeySet
from ory_client.model.keto_namespace import KetoNamespace
from ory_client.model.keto_namespaces import KetoNamespaces
from ory_client.model.list_custom_domains import ListCustomDomains
from ory_client.model.login_flow import LoginFlow
from ory_client.model.logout_flow import LogoutFlow
from ory_client.model.managed_identity_schema import ManagedIdentitySchema
from ory_client.model.managed_identity_schema_validation_result import ManagedIdentitySchemaValidationResult
from ory_client.model.managed_identity_schemas import ManagedIdentitySchemas
from ory_client.model.message import Message
from ory_client.model.message_dispatch import MessageDispatch
from ory_client.model.namespace import Namespace
from ory_client.model.needs_privileged_session_error import NeedsPrivilegedSessionError
from ory_client.model.normalized_project import NormalizedProject
from ory_client.model.normalized_project_revision import NormalizedProjectRevision
from ory_client.model.normalized_project_revision_hook import NormalizedProjectRevisionHook
from ory_client.model.normalized_project_revision_identity_schema import NormalizedProjectRevisionIdentitySchema
from ory_client.model.normalized_project_revision_identity_schemas import NormalizedProjectRevisionIdentitySchemas
from ory_client.model.normalized_project_revision_third_party_provider import NormalizedProjectRevisionThirdPartyProvider
from ory_client.model.normalized_projects import NormalizedProjects
from ory_client.model.null_duration import NullDuration
from ory_client.model.o_auth2_client import OAuth2Client
from ory_client.model.o_auth2_client_token_lifespans import OAuth2ClientTokenLifespans
from ory_client.model.o_auth2_consent_request import OAuth2ConsentRequest
from ory_client.model.o_auth2_consent_request_open_id_connect_context import OAuth2ConsentRequestOpenIDConnectContext
from ory_client.model.o_auth2_consent_session import OAuth2ConsentSession
from ory_client.model.o_auth2_consent_session_expires_at import OAuth2ConsentSessionExpiresAt
from ory_client.model.o_auth2_consent_sessions import OAuth2ConsentSessions
from ory_client.model.o_auth2_login_request import OAuth2LoginRequest
from ory_client.model.o_auth2_logout_request import OAuth2LogoutRequest
from ory_client.model.o_auth2_redirect_to import OAuth2RedirectTo
from ory_client.model.o_auth2_token_exchange import OAuth2TokenExchange
from ory_client.model.oidc_configuration import OidcConfiguration
from ory_client.model.oidc_user_info import OidcUserInfo
from ory_client.model.pagination import Pagination
from ory_client.model.pagination_headers import PaginationHeaders
from ory_client.model.parse_error import ParseError
from ory_client.model.patch_identities_body import PatchIdentitiesBody
from ory_client.model.perform_native_logout_body import PerformNativeLogoutBody
from ory_client.model.permissions_on_project import PermissionsOnProject
from ory_client.model.plan import Plan
from ory_client.model.plan_details import PlanDetails
from ory_client.model.plans import Plans
from ory_client.model.post_check_permission_body import PostCheckPermissionBody
from ory_client.model.post_check_permission_or_error_body import PostCheckPermissionOrErrorBody
from ory_client.model.pricing import Pricing
from ory_client.model.project import Project
from ory_client.model.project_api_key import ProjectApiKey
from ory_client.model.project_api_keys import ProjectApiKeys
from ory_client.model.project_branding import ProjectBranding
from ory_client.model.project_branding_colors import ProjectBrandingColors
from ory_client.model.project_branding_theme import ProjectBrandingTheme
from ory_client.model.project_branding_themes import ProjectBrandingThemes
from ory_client.model.project_host import ProjectHost
from ory_client.model.project_invite import ProjectInvite
from ory_client.model.project_invites import ProjectInvites
from ory_client.model.project_member import ProjectMember
from ory_client.model.project_members import ProjectMembers
from ory_client.model.project_metadata import ProjectMetadata
from ory_client.model.project_metadata_list import ProjectMetadataList
from ory_client.model.project_revision_hooks import ProjectRevisionHooks
from ory_client.model.project_revision_identity_schemas import ProjectRevisionIdentitySchemas
from ory_client.model.project_revision_third_party_login_providers import ProjectRevisionThirdPartyLoginProviders
from ory_client.model.project_revisions import ProjectRevisions
from ory_client.model.project_service_identity import ProjectServiceIdentity
from ory_client.model.project_service_o_auth2 import ProjectServiceOAuth2
from ory_client.model.project_service_permission import ProjectServicePermission
from ory_client.model.project_services import ProjectServices
from ory_client.model.projects import Projects
from ory_client.model.quota_usage import QuotaUsage
from ory_client.model.recovery_code_for_identity import RecoveryCodeForIdentity
from ory_client.model.recovery_flow import RecoveryFlow
from ory_client.model.recovery_flow_state import RecoveryFlowState
from ory_client.model.recovery_identity_address import RecoveryIdentityAddress
from ory_client.model.recovery_link_for_identity import RecoveryLinkForIdentity
from ory_client.model.registration_flow import RegistrationFlow
from ory_client.model.reject_o_auth2_request import RejectOAuth2Request
from ory_client.model.relation_query import RelationQuery
from ory_client.model.relationship import Relationship
from ory_client.model.relationship_namespaces import RelationshipNamespaces
from ory_client.model.relationship_patch import RelationshipPatch
from ory_client.model.relationships import Relationships
from ory_client.model.schema_patch import SchemaPatch
from ory_client.model.self_service_flow_expired_error import SelfServiceFlowExpiredError
from ory_client.model.session import Session
from ory_client.model.session_authentication_method import SessionAuthenticationMethod
from ory_client.model.session_authentication_methods import SessionAuthenticationMethods
from ory_client.model.session_device import SessionDevice
from ory_client.model.set_active_project_in_console_body import SetActiveProjectInConsoleBody
from ory_client.model.set_custom_domain_body import SetCustomDomainBody
from ory_client.model.set_project import SetProject
from ory_client.model.set_project_branding_theme_body import SetProjectBrandingThemeBody
from ory_client.model.settings_flow import SettingsFlow
from ory_client.model.settings_flow_state import SettingsFlowState
from ory_client.model.source_position import SourcePosition
from ory_client.model.string_slice_json_format import StringSliceJSONFormat
from ory_client.model.stripe_customer import StripeCustomer
from ory_client.model.subject_set import SubjectSet
from ory_client.model.subscription import Subscription
from ory_client.model.successful_code_exchange_response import SuccessfulCodeExchangeResponse
from ory_client.model.successful_native_login import SuccessfulNativeLogin
from ory_client.model.successful_native_registration import SuccessfulNativeRegistration
from ory_client.model.successful_project_update import SuccessfulProjectUpdate
from ory_client.model.token_pagination import TokenPagination
from ory_client.model.token_pagination_headers import TokenPaginationHeaders
from ory_client.model.token_pagination_request_parameters import TokenPaginationRequestParameters
from ory_client.model.token_pagination_response_headers import TokenPaginationResponseHeaders
from ory_client.model.trust_o_auth2_jwt_grant_issuer import TrustOAuth2JwtGrantIssuer
from ory_client.model.trusted_o_auth2_jwt_grant_issuer import TrustedOAuth2JwtGrantIssuer
from ory_client.model.trusted_o_auth2_jwt_grant_issuers import TrustedOAuth2JwtGrantIssuers
from ory_client.model.trusted_o_auth2_jwt_grant_json_web_key import TrustedOAuth2JwtGrantJsonWebKey
from ory_client.model.ui_container import UiContainer
from ory_client.model.ui_node import UiNode
from ory_client.model.ui_node_anchor_attributes import UiNodeAnchorAttributes
from ory_client.model.ui_node_attributes import UiNodeAttributes
from ory_client.model.ui_node_image_attributes import UiNodeImageAttributes
from ory_client.model.ui_node_input_attributes import UiNodeInputAttributes
from ory_client.model.ui_node_meta import UiNodeMeta
from ory_client.model.ui_node_script_attributes import UiNodeScriptAttributes
from ory_client.model.ui_node_text_attributes import UiNodeTextAttributes
from ory_client.model.ui_nodes import UiNodes
from ory_client.model.ui_text import UiText
from ory_client.model.ui_texts import UiTexts
from ory_client.model.update_identity_body import UpdateIdentityBody
from ory_client.model.update_login_flow_body import UpdateLoginFlowBody
from ory_client.model.update_login_flow_with_lookup_secret_method import UpdateLoginFlowWithLookupSecretMethod
from ory_client.model.update_login_flow_with_oidc_method import UpdateLoginFlowWithOidcMethod
from ory_client.model.update_login_flow_with_password_method import UpdateLoginFlowWithPasswordMethod
from ory_client.model.update_login_flow_with_totp_method import UpdateLoginFlowWithTotpMethod
from ory_client.model.update_login_flow_with_web_authn_method import UpdateLoginFlowWithWebAuthnMethod
from ory_client.model.update_recovery_flow_body import UpdateRecoveryFlowBody
from ory_client.model.update_recovery_flow_with_code_method import UpdateRecoveryFlowWithCodeMethod
from ory_client.model.update_recovery_flow_with_link_method import UpdateRecoveryFlowWithLinkMethod
from ory_client.model.update_registration_flow_body import UpdateRegistrationFlowBody
from ory_client.model.update_registration_flow_with_oidc_method import UpdateRegistrationFlowWithOidcMethod
from ory_client.model.update_registration_flow_with_password_method import UpdateRegistrationFlowWithPasswordMethod
from ory_client.model.update_registration_flow_with_web_authn_method import UpdateRegistrationFlowWithWebAuthnMethod
from ory_client.model.update_settings_flow_body import UpdateSettingsFlowBody
from ory_client.model.update_settings_flow_with_lookup_method import UpdateSettingsFlowWithLookupMethod
from ory_client.model.update_settings_flow_with_oidc_method import UpdateSettingsFlowWithOidcMethod
from ory_client.model.update_settings_flow_with_password_method import UpdateSettingsFlowWithPasswordMethod
from ory_client.model.update_settings_flow_with_profile_method import UpdateSettingsFlowWithProfileMethod
from ory_client.model.update_settings_flow_with_totp_method import UpdateSettingsFlowWithTotpMethod
from ory_client.model.update_settings_flow_with_web_authn_method import UpdateSettingsFlowWithWebAuthnMethod
from ory_client.model.update_subscription_body import UpdateSubscriptionBody
from ory_client.model.update_verification_flow_body import UpdateVerificationFlowBody
from ory_client.model.update_verification_flow_with_code_method import UpdateVerificationFlowWithCodeMethod
from ory_client.model.update_verification_flow_with_link_method import UpdateVerificationFlowWithLinkMethod
from ory_client.model.usage import Usage
from ory_client.model.verifiable_identity_address import VerifiableIdentityAddress
from ory_client.model.verification_flow import VerificationFlow
from ory_client.model.verification_flow_state import VerificationFlowState
from ory_client.model.version import Version
from ory_client.model.warning import Warning



"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v1.1.33
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.authenticator_assurance_level import AuthenticatorAssuranceLevel
from ory_client.model.identity import Identity
from ory_client.model.session_authentication_methods import SessionAuthenticationMethods
from ory_client.model.session_device import SessionDevice
globals()['AuthenticatorAssuranceLevel'] = AuthenticatorAssuranceLevel
globals()['Identity'] = Identity
globals()['SessionAuthenticationMethods'] = SessionAuthenticationMethods
globals()['SessionDevice'] = SessionDevice
from ory_client.model.session import Session


class TestSession(unittest.TestCase):
    """Session unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSession(self):
        """Test Session"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Session()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v1.1.33
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.identity_state import IdentityState
from ory_client.model.identity_with_credentials import IdentityWithCredentials
from ory_client.model.recovery_identity_address import RecoveryIdentityAddress
from ory_client.model.verifiable_identity_address import VerifiableIdentityAddress
globals()['IdentityState'] = IdentityState
globals()['IdentityWithCredentials'] = IdentityWithCredentials
globals()['RecoveryIdentityAddress'] = RecoveryIdentityAddress
globals()['VerifiableIdentityAddress'] = VerifiableIdentityAddress
from ory_client.model.create_identity_body import CreateIdentityBody


class TestCreateIdentityBody(unittest.TestCase):
    """CreateIdentityBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateIdentityBody(self):
        """Test CreateIdentityBody"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateIdentityBody()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
